Computes the number of cells per clone per patient, producing the
clone_counts data frame required by predict_patients().
Computes the number of cells per clone per patient, producing the
clone_counts data frame required by predict_patients().